@@ -13,14 +13,14 @@ async def main():
         'secretKey': read_secret('coin', 'binance', 'secret_key')
     }
     exchange = ccxtpro.binance(d)
-    await exchange.watch_trades('BTC/USDT')
-    await exchange.watch_trades('ETC/USDT')
+    await exchange.watch_trades('BTC/BUSD')
+    await exchange.watch_trades('ETC/BUSD')
     while True:
         try:
             trades = exchange.trades
             # trades = await exchange.watch_trades('BTC/USDT')
-            print((1, len(trades['BTC/USDT']), len(trades['ETC/USDT'])))
-
+            print((1, len(trades['BTC/BUSD']), len(trades['ETC/BUSD'])))
+            print(trades['BTC/BUSD'][-1])
             # orderbook = await exchange.watch_ohlcv('BTC/USD')
             # orderbook = await exchange.watch_orders()
 
@@ -28,7 +28,7 @@ async def main():
             # print(orderbook['asks'][0], orderbook['bids'][0])
             # print(await exchange.watch_trades('BTC/USDT'))
             # await exchange.sleep(5)
-            time.sleep(1)
+            # time.sleep(1)
             await exchange.sleep(100)
         except Exception as e:
             print(e)
