@@ -34,7 +34,7 @@ class AccountTask(BaseTask):
     def __init__(self, *args, **kwargs):
         super(AccountTask, self).__init__(*args, **kwargs)
 
-    def refresh(self):
+    def refresh(self,conn=None):
         data = self.exchange.fetch_balance()
         df = pd.DataFrame([data['total'], data['free'], data['used']]).transpose()
         df.columns = ['total', 'free', 'used']
@@ -49,7 +49,7 @@ class AccountTask(BaseTask):
             return self.current_price(f"{data['symbol']}/BUSD")
 
         account['price'] = account[['symbol', 'total']].apply(fun, axis=1)
-        account.to_sql(name=self.table_name, con=self.engine.connect(), if_exists='replace')
+        account.to_sql(name=self.table_name, con=conn or self.engine.connect(), if_exists='replace')
 
 
 class MarketTask(BaseTask):
@@ -58,10 +58,10 @@ class MarketTask(BaseTask):
     def __init__(self, *args, **kwargs):
         super(MarketTask, self).__init__(*args, **kwargs)
 
-    def refresh(self):
+    def refresh(self,conn = None):
         self.exchange.load_markets()
         df = pd.DataFrame([dict((k, str(v)) for k, v in symbol.items()) for symbol in self.exchange.markets.values()])
-        df.to_sql(name=self.table_name, con=self.engine.connect(), if_exists='replace')
+        df.to_sql(name=self.table_name, con=conn or self.engine.connect(), if_exists='replace')
 
 
 class Ticker24HTask(BaseTask):
@@ -70,12 +70,12 @@ class Ticker24HTask(BaseTask):
     def __init__(self, *args, **kwargs):
         super(Ticker24HTask, self).__init__(*args, **kwargs)
 
-    def refresh(self):
+    def refresh(self,conn=None):
         param = {"type": "MINI"}
         df = pd.DataFrame(self.exchange.public_get_ticker_24hr(param))
         dtype = {
             'volume': DOUBLE,
             'quoteVolume': DOUBLE
         }
-        df.to_sql(name=self.table_name, con=self.engine.connect(), if_exists='replace',
+        df.to_sql(name=self.table_name, con=conn or self.engine.connect(), if_exists='replace',
                   dtype=dtype)
