@@ -1,15 +1,25 @@
 from datetime import datetime, timedelta
 
 
+def year_first_datetime(years):
+    today = datetime.today()
+    return datetime(today.year + years, 1, 1)
+
+
 def month_first_datetime(months):
     today = datetime.today()
     months = today.month + months - 1
     years = -int((months % 12 - months) / 12)
     months = months % 12 + 1
-
     return datetime(today.year + years, months, 1)
 
 
+def year_during(years):
+    first = year_first_datetime(years)
+    last = year_first_datetime(years + 1) - timedelta(seconds=1)
+    return first, last
+
+
 def month_during(months):
     first = month_first_datetime(months)
     last = month_first_datetime(months + 1) - timedelta(seconds=1)
